@@ -214,7 +214,7 @@ eval
             # Generate coverage summary
             &log(INFO, "Generate Coverage Summary");
             executeTest(
-                "${strTestExe} --no-valgrind --clean --no-optimize --vm-max=3 --coverage-summary",
+                "${strTestExe} --vm=f32 --no-valgrind --clean --no-optimize --vm-max=3 --coverage-summary",
                 {bShowOutputAsync => true});
         }
 
