@@ -284,6 +284,18 @@ archiveAsyncExec(ArchiveMode archiveMode, const StringList *commandExec)
     FUNCTION_LOG_RETURN_VOID();
 }
 
+/**********************************************************************************************************************************/
+int
+archiveIdComparator(const void *item1, const void *item2)
+{
+    StringList *archiveSort1 = strLstNewSplitZ(*(String **)item1, "-");
+    StringList *archiveSort2 = strLstNewSplitZ(*(String **)item2, "-");
+    int int1 = atoi(strZ(strLstGet(archiveSort1, 1)));
+    int int2 = atoi(strZ(strLstGet(archiveSort2, 1)));
+
+    return (int1 - int2);
+}
+
 /**********************************************************************************************************************************/
 bool
 walIsPartial(const String *walSegment)
@@ -340,10 +352,16 @@ walPath(const String *walFile, const String *pgPath, const String *command)
             char newWorkDir[4096];
             THROW_ON_SYS_ERROR(getcwd(newWorkDir, sizeof(newWorkDir)) == NULL, FormatError, "unable to get cwd");
 
-            // Error if the new working directory is not equal to the original current working directory.  This means that
-            // PostgreSQL and pgBackrest have a different idea about where the PostgreSQL data directory is located.
+            // Error if the new working directory is not equal to the original current working directory. This means that PostgreSQL
+            // and pgBackrest have a different idea about where the PostgreSQL data directory is located.
             if (strcmp(currentWorkDir, newWorkDir) != 0)
-                THROW_FMT(AssertError, "working path '%s' is not the same path as '%s'", currentWorkDir, strZ(pgPath));
+            {
+                THROW_FMT(
+                    OptionInvalidValueError,
+                    PG_NAME " working directory '%s' is not the same as option " CFGOPT_PG1_PATH " '%s'\n"
+                        "HINT: is the " PG_NAME " data_directory configured the same as the " CFGOPT_PG1_PATH " option?",
+                    currentWorkDir, strZ(pgPath));
+            }
         }
 
         result = strNewFmt("%s/%s", strZ(pgPath), strZ(walFile));
@@ -442,7 +460,8 @@ walSegmentFind(const Storage *storage, const String *archiveId, const String *wa
             ArchiveTimeoutError,
             "WAL segment %s was not archived before the %" PRIu64 "ms timeout\n"
                 "HINT: check the archive_command to ensure that all options are correct (especially --stanza).\n"
-                "HINT: check the PostgreSQL server log for errors.",
+                "HINT: check the PostgreSQL server log for errors.\n"
+                "HINT: run the 'start' command if the stanza was previously stopped.",
             strZ(walSegment), timeout);
     }
 
