@@ -46,7 +46,7 @@ restoreProtocol(const String *command, const VariantList *paramList, ProtocolSer
                         varStr(varLstGet(paramList, 0)), varStr(varLstGet(paramList, 1)),
                         (CompressType)varUIntForce(varLstGet(paramList, 2)), varStr(varLstGet(paramList, 3)),
                         varStr(varLstGet(paramList, 4)), varBoolForce(varLstGet(paramList, 5)), varUInt64(varLstGet(paramList, 6)),
-                        (time_t)varInt64Force(varLstGet(paramList, 7)), cvtZToUIntBase(strPtr(varStr(varLstGet(paramList, 8))), 8),
+                        (time_t)varInt64Force(varLstGet(paramList, 7)), cvtZToUIntBase(strZ(varStr(varLstGet(paramList, 8))), 8),
                         varStr(varLstGet(paramList, 9)), varStr(varLstGet(paramList, 10)),
                         (time_t)varInt64Force(varLstGet(paramList, 11)), varBoolForce(varLstGet(paramList, 12)),
                         varBoolForce(varLstGet(paramList, 13)), varStr(varLstGet(paramList, 14)))));
