@@ -35,6 +35,11 @@ Hashes for zero-length files (i.e., seed value)
 STRING_EXTERN(HASH_TYPE_SHA1_ZERO_STR,                              HASH_TYPE_SHA1_ZERO);
 STRING_EXTERN(HASH_TYPE_SHA256_ZERO_STR,                            HASH_TYPE_SHA256_ZERO);
 
+/***********************************************************************************************************************************
+Include local MD5 code
+***********************************************************************************************************************************/
+#include "common/crypto/md5.vendor.c"
+
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
@@ -46,6 +51,7 @@ typedef struct CryptoHash
     MemContext *memContext;                                         // Context to store data
     const EVP_MD *hashType;                                         // Hash type (sha1, md5, etc.)
     EVP_MD_CTX *hashContext;                                        // Message hash context
+    MD5_CTX *md5Context;                                            // MD5 context (used to bypass FIPS restrictions)
     Buffer *hash;                                                   // Hash in binary form
 } CryptoHash;
 
@@ -80,11 +86,17 @@ cryptoHashProcess(THIS_VOID, const Buffer *message)
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
-    ASSERT(this->hashContext != NULL);
     ASSERT(this->hash == NULL);
     ASSERT(message != NULL);
 
-    cryptoError(!EVP_DigestUpdate(this->hashContext, bufPtrConst(message), bufUsed(message)), "unable to process message hash");
+    // Standard OpenSSL implementation
+    if (this->hashContext != NULL)
+    {
+        cryptoError(!EVP_DigestUpdate(this->hashContext, bufPtrConst(message), bufUsed(message)), "unable to process message hash");
+    }
+    // Else local MD5 implementation
+    else
+        MD5_Update(this->md5Context, bufPtrConst(message), bufUsed(message));
 
     FUNCTION_LOG_RETURN_VOID();
 }
@@ -105,10 +117,20 @@ cryptoHash(CryptoHash *this)
     {
         MEM_CONTEXT_BEGIN(this->memContext)
         {
-            this->hash = bufNew((size_t)EVP_MD_size(this->hashType));
-            bufUsedSet(this->hash, bufSize(this->hash));
+            // Standard OpenSSL implementation
+            if (this->hashContext != NULL)
+            {
+                this->hash = bufNew((size_t)EVP_MD_size(this->hashType));
+                cryptoError(!EVP_DigestFinal_ex(this->hashContext, bufPtr(this->hash), NULL), "unable to finalize message hash");
+            }
+            // Else local MD5 implementation
+            else
+            {
+                this->hash = bufNew(HASH_TYPE_M5_SIZE);
+                MD5_Final(bufPtr(this->hash), this->md5Context);
+            }
 
-            cryptoError(!EVP_DigestFinal_ex(this->hashContext, bufPtr(this->hash), NULL), "unable to finalize message hash");
+            bufUsedSet(this->hash, bufSize(this->hash));
         }
         MEM_CONTEXT_END();
     }
@@ -158,18 +180,31 @@ cryptoHashNew(const String *type)
             .memContext = MEM_CONTEXT_NEW(),
         };
 
-        // Lookup digest
-        if ((driver->hashType = EVP_get_digestbyname(strPtr(type))) == NULL)
-            THROW_FMT(AssertError, "unable to load hash '%s'", strPtr(type));
+        // Use local MD5 implementation since FIPS-enabled systems do not allow MD5. This is a bit misguided since there are valid
+        // cases for using MD5 which do not involve, for example, password hashes. Since popular object stores, e.g. S3, require
+        // MD5 for verifying payload integrity we are simply forced to provide MD5 functionality.
+        if (strEq(type, HASH_TYPE_MD5_STR))
+        {
+            driver->md5Context = memNew(sizeof(MD5_CTX));
 
-        // Create context
-        cryptoError((driver->hashContext = EVP_MD_CTX_create()) == NULL, "unable to create hash context");
+            MD5_Init(driver->md5Context);
+        }
+        // Else use the standard OpenSSL implementation
+        else
+        {
+            // Lookup digest
+            if ((driver->hashType = EVP_get_digestbyname(strZ(type))) == NULL)
+                THROW_FMT(AssertError, "unable to load hash '%s'", strZ(type));
 
-        // Set free callback to ensure hash context is freed
-        memContextCallbackSet(driver->memContext, cryptoHashFreeResource, driver);
+            // Create context
+            cryptoError((driver->hashContext = EVP_MD_CTX_create()) == NULL, "unable to create hash context");
 
-        // Initialize context
-        cryptoError(!EVP_DigestInit_ex(driver->hashContext, driver->hashType, NULL), "unable to initialize hash context");
+            // Set free callback to ensure hash context is freed
+            memContextCallbackSet(driver->memContext, cryptoHashFreeResource, driver);
+
+            // Initialize context
+            cryptoError(!EVP_DigestInit_ex(driver->hashContext, driver->hashType, NULL), "unable to initialize hash context");
+        }
 
         // Create param list
         VariantList *paramList = varLstNew();
@@ -237,7 +272,10 @@ cryptoHmacOne(const String *type, const Buffer *key, const Buffer *message)
     ASSERT(key != NULL);
     ASSERT(message != NULL);
 
-    const EVP_MD *hashType = EVP_get_digestbyname(strPtr(type));
+    // Init crypto subsystem
+    cryptoInit();
+
+    const EVP_MD *hashType = EVP_get_digestbyname(strZ(type));
     ASSERT(hashType != NULL);
 
     // Allocate a buffer to hold the hmac
