@@ -68,14 +68,14 @@ jsonToBool(const String *json)
     FUNCTION_TEST_END();
 
     unsigned int jsonPos = 0;
-    jsonConsumeWhiteSpace(strPtr(json), &jsonPos);
+    jsonConsumeWhiteSpace(strZ(json), &jsonPos);
 
-    bool result = jsonToBoolInternal(strPtr(json), &jsonPos);
+    bool result = jsonToBoolInternal(strZ(json), &jsonPos);
 
-    jsonConsumeWhiteSpace(strPtr(json), &jsonPos);
+    jsonConsumeWhiteSpace(strZ(json), &jsonPos);
 
     if (jsonPos != strSize(json))
-        THROW_FMT(JsonFormatError, "unexpected characters after boolean at '%s'", strPtr(json) + jsonPos);
+        THROW_FMT(JsonFormatError, "unexpected characters after boolean at '%s'", strZ(json) + jsonPos);
 
     FUNCTION_TEST_RETURN(result);
 }
@@ -117,9 +117,9 @@ jsonToNumberInternal(const char *json, unsigned int *jsonPos)
         MEM_CONTEXT_PRIOR_BEGIN()
         {
             if (intSigned)
-                result = varNewInt64(cvtZToInt64(strPtr(resultStr)));
+                result = varNewInt64(cvtZToInt64(strZ(resultStr)));
             else
-                result = varNewUInt64(cvtZToUInt64(strPtr(resultStr)));
+                result = varNewUInt64(cvtZToUInt64(strZ(resultStr)));
         }
         MEM_CONTEXT_PRIOR_END();
     }
@@ -136,14 +136,14 @@ jsonToNumber(const String *json)
     FUNCTION_TEST_END();
 
     unsigned int jsonPos = 0;
-    jsonConsumeWhiteSpace(strPtr(json), &jsonPos);
+    jsonConsumeWhiteSpace(strZ(json), &jsonPos);
 
-    Variant *result = jsonToNumberInternal(strPtr(json), &jsonPos);
+    Variant *result = jsonToNumberInternal(strZ(json), &jsonPos);
 
-    jsonConsumeWhiteSpace(strPtr(json), &jsonPos);
+    jsonConsumeWhiteSpace(strZ(json), &jsonPos);
 
     if (jsonPos != strSize(json))
-        THROW_FMT(JsonFormatError, "unexpected characters after number at '%s'", strPtr(json) + jsonPos);
+        THROW_FMT(JsonFormatError, "unexpected characters after number at '%s'", strZ(json) + jsonPos);
 
     FUNCTION_TEST_RETURN(result);
 }
@@ -329,19 +329,19 @@ jsonToStr(const String *json)
     FUNCTION_TEST_END();
 
     unsigned int jsonPos = 0;
-    jsonConsumeWhiteSpace(strPtr(json), &jsonPos);
+    jsonConsumeWhiteSpace(strZ(json), &jsonPos);
 
     String *result = NULL;
 
-    if (strncmp(strPtr(json), NULL_Z, 4) == 0)
+    if (strncmp(strZ(json), NULL_Z, 4) == 0)
         jsonPos += 4;
     else
-        result = jsonToStrInternal(strPtr(json), &jsonPos);
+        result = jsonToStrInternal(strZ(json), &jsonPos);
 
-    jsonConsumeWhiteSpace(strPtr(json), &jsonPos);
+    jsonConsumeWhiteSpace(strZ(json), &jsonPos);
 
     if (jsonPos != strSize(json))
-        THROW_FMT(JsonFormatError, "unexpected characters after string at '%s'", strPtr(json) + jsonPos);
+        THROW_FMT(JsonFormatError, "unexpected characters after string at '%s'", strZ(json) + jsonPos);
 
     FUNCTION_TEST_RETURN(result);
 }
@@ -406,17 +406,17 @@ jsonToKv(const String *json)
     FUNCTION_TEST_END();
 
     unsigned int jsonPos = 0;
-    jsonConsumeWhiteSpace(strPtr(json), &jsonPos);
+    jsonConsumeWhiteSpace(strZ(json), &jsonPos);
 
-    if (strPtr(json)[jsonPos] != '{')
-        THROW_FMT(JsonFormatError, "expected '{' at '%s'", strPtr(json) + jsonPos);
+    if (strZ(json)[jsonPos] != '{')
+        THROW_FMT(JsonFormatError, "expected '{' at '%s'", strZ(json) + jsonPos);
 
-    KeyValue *result = jsonToKvInternal(strPtr(json), &jsonPos);
+    KeyValue *result = jsonToKvInternal(strZ(json), &jsonPos);
 
-    jsonConsumeWhiteSpace(strPtr(json), &jsonPos);
+    jsonConsumeWhiteSpace(strZ(json), &jsonPos);
 
     if (jsonPos != strSize(json))
-        THROW_FMT(JsonFormatError, "unexpected characters after object at '%s'", strPtr(json) + jsonPos);
+        THROW_FMT(JsonFormatError, "unexpected characters after object at '%s'", strZ(json) + jsonPos);
 
     FUNCTION_TEST_RETURN(result);
 }
@@ -481,14 +481,14 @@ jsonToVarLst(const String *json)
     FUNCTION_TEST_END();
 
     unsigned int jsonPos = 0;
-    jsonConsumeWhiteSpace(strPtr(json), &jsonPos);
+    jsonConsumeWhiteSpace(strZ(json), &jsonPos);
 
-    VariantList *result = jsonToVarLstInternal(strPtr(json), &jsonPos);
+    VariantList *result = jsonToVarLstInternal(strZ(json), &jsonPos);
 
-    jsonConsumeWhiteSpace(strPtr(json), &jsonPos);
+    jsonConsumeWhiteSpace(strZ(json), &jsonPos);
 
     if (jsonPos != strSize(json))
-        THROW_FMT(JsonFormatError, "unexpected characters after array at '%s'", strPtr(json) + jsonPos);
+        THROW_FMT(JsonFormatError, "unexpected characters after array at '%s'", strZ(json) + jsonPos);
 
     FUNCTION_TEST_RETURN(result);
 }
@@ -581,10 +581,15 @@ jsonToVar(const String *json)
         FUNCTION_LOG_PARAM(STRING, json);
     FUNCTION_LOG_END();
 
-    const char *jsonPtr = strPtr(json);
+    const char *jsonPtr = strZ(json);
     unsigned int jsonPos = 0;
 
-    FUNCTION_LOG_RETURN(VARIANT, jsonToVarInternal(jsonPtr, &jsonPos));
+    Variant *result = jsonToVarInternal(jsonPtr, &jsonPos);
+
+    if (jsonPos != strSize(json))
+        THROW_FMT(JsonFormatError, "unexpected characters after JSON at '%s'", strZ(json) + jsonPos);
+
+    FUNCTION_LOG_RETURN(VARIANT, result);
 }
 
 /**********************************************************************************************************************************/
@@ -665,7 +670,7 @@ jsonFromStrInternal(String *json, const String *string)
     // If string is null
     if (string == NULL)
     {
-        strCat(json, NULL_Z);
+        strCat(json, NULL_STR);
     }
     // Else escape and output string
     else
@@ -678,7 +683,7 @@ jsonFromStrInternal(String *json, const String *string)
 
         for (unsigned int stringIdx = 0; stringIdx < strSize(string); stringIdx++)
         {
-            char stringChr = strPtr(string)[stringIdx];
+            char stringChr = strZ(string)[stringIdx];
 
             switch (stringChr)
             {
@@ -701,43 +706,43 @@ jsonFromStrInternal(String *json, const String *string)
                     {
                         case '"':
                         {
-                            strCat(json, "\\\"");
+                            strCatZ(json, "\\\"");
                             break;
                         }
 
                         case '\\':
                         {
-                            strCat(json, "\\\\");
+                            strCatZ(json, "\\\\");
                             break;
                         }
 
                         case '\n':
                         {
-                            strCat(json, "\\n");
+                            strCatZ(json, "\\n");
                             break;
                         }
 
                         case '\r':
                         {
-                            strCat(json, "\\r");
+                            strCatZ(json, "\\r");
                             break;
                         }
 
                         case '\t':
                         {
-                            strCat(json, "\\t");
+                            strCatZ(json, "\\t");
                             break;
                         }
 
                         case '\b':
                         {
-                            strCat(json, "\\b");
+                            strCatZ(json, "\\b");
                             break;
                         }
 
                         case '\f':
                         {
-                            strCat(json, "\\f");
+                            strCatZ(json, "\\f");
                             break;
                         }
                     }
@@ -749,7 +754,7 @@ jsonFromStrInternal(String *json, const String *string)
                 {
                     // If escape string is zero size then start it
                     if (noEscapeSize == 0)
-                        noEscape = strPtr(string) + stringIdx;
+                        noEscape = strZ(string) + stringIdx;
 
                     noEscapeSize++;
                     break;
@@ -805,21 +810,21 @@ jsonFromKvInternal(const KeyValue *kv)
 
             // If going to add another key, prepend a comma
             if (keyIdx > 0)
-                strCat(result, ",");
+                strCatZ(result, ",");
 
             // Keys are always strings in the output, so add starting quote and colon.
-            strCatFmt(result, "\"%s\":", strPtr(key));
+            strCatFmt(result, "\"%s\":", strZ(key));
 
             // NULL value
             if (value == NULL)
-                strCat(result, NULL_Z);
+                strCat(result, NULL_STR);
             else
             {
                 switch (varType(value))
                 {
                     case varTypeKeyValue:
                     {
-                        strCat(result, strPtr(jsonFromKvInternal(kvDup(varKv(value)))));
+                        strCat(result, jsonFromKvInternal(kvDup(varKv(value))));
                         break;
                     }
 
@@ -827,12 +832,12 @@ jsonFromKvInternal(const KeyValue *kv)
                     {
                         // If the array is empty, then do not add formatting, else process the array.
                         if (varVarLst(value) == NULL)
-                            strCat(result, NULL_Z);
+                            strCat(result, NULL_STR);
                         else if (varLstSize(varVarLst(value)) == 0)
-                            strCat(result, "[]");
+                            strCatZ(result, "[]");
                         else
                         {
-                            strCat(result, "[");
+                            strCatZ(result, "[");
 
                             for (unsigned int arrayIdx = 0; arrayIdx < varLstSize(varVarLst(value)); arrayIdx++)
                             {
@@ -840,12 +845,12 @@ jsonFromKvInternal(const KeyValue *kv)
 
                                 // If going to add another element, add a comma
                                 if (arrayIdx > 0)
-                                    strCat(result, ",");
+                                    strCatZ(result, ",");
 
                                 // If array value is null
                                 if (arrayValue == NULL)
                                 {
-                                    strCat(result, NULL_Z);
+                                    strCat(result, NULL_STR);
                                 }
                                 // If the type is a string, add leading and trailing double quotes
                                 else if (varType(arrayValue) == varTypeString)
@@ -854,18 +859,18 @@ jsonFromKvInternal(const KeyValue *kv)
                                 }
                                 else if (varType(arrayValue) == varTypeKeyValue)
                                 {
-                                    strCat(result, strPtr(jsonFromKvInternal(kvDup(varKv(arrayValue)))));
+                                    strCat(result, jsonFromKvInternal(kvDup(varKv(arrayValue))));
                                 }
                                 else if (varType(arrayValue) == varTypeVariantList)
                                 {
-                                    strCat(result, strPtr(jsonFromVar(arrayValue)));
+                                    strCat(result, jsonFromVar(arrayValue));
                                 }
                                 // Numeric, Boolean or other type
                                 else
-                                    strCat(result, strPtr(varStrForce(arrayValue)));
+                                    strCat(result, varStrForce(arrayValue));
                             }
 
-                            strCat(result, "]");
+                            strCatZ(result, "]");
                         }
 
                         break;
@@ -880,14 +885,14 @@ jsonFromKvInternal(const KeyValue *kv)
 
                     default:
                     {
-                        strCat(result, strPtr(varStrForce(value)));
+                        strCat(result, varStrForce(value));
                         break;
                     }
                 }
             }
         }
 
-        result = strCat(result, "}");
+        result = strCatZ(result, "}");
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -946,19 +951,19 @@ jsonFromVar(const Variant *var)
         // If VariantList then process each item in the array. Currently the list must be KeyValue types.
         if (var == NULL)
         {
-            strCat(jsonStr, strPtr(NULL_STR));
+            strCat(jsonStr, NULL_STR);
         }
         else if (varType(var) == varTypeBool)
         {
-            strCat(jsonStr, strPtr(jsonFromBool(varBool(var))));
+            strCat(jsonStr, jsonFromBool(varBool(var)));
         }
         else if (varType(var) == varTypeUInt)
         {
-            strCat(jsonStr, strPtr(jsonFromUInt(varUInt(var))));
+            strCat(jsonStr, jsonFromUInt(varUInt(var)));
         }
         else if (varType(var) == varTypeUInt64)
         {
-            strCat(jsonStr, strPtr(jsonFromUInt64(varUInt64(var))));
+            strCat(jsonStr, jsonFromUInt64(varUInt64(var)));
         }
         else if (varType(var) == varTypeString)
         {
@@ -971,63 +976,63 @@ jsonFromVar(const Variant *var)
             // If not an empty array
             if (varLstSize(vl) > 0)
             {
-                strCat(jsonStr, "[");
+                strCatZ(jsonStr, "[");
 
                 // Currently only KeyValue and String lists are supported
                 for (unsigned int vlIdx = 0; vlIdx < varLstSize(vl); vlIdx++)
                 {
                     // If going to add another key, append a comma
                     if (vlIdx > 0)
-                        strCat(jsonStr, ",");
+                        strCatZ(jsonStr, ",");
 
                     Variant *varSub = varLstGet(vl, vlIdx);
 
                     if (varSub == NULL)
                     {
-                        strCat(jsonStr, NULL_Z);
+                        strCat(jsonStr, NULL_STR);
                     }
                     else if (varType(varSub) == varTypeBool)
                     {
-                        strCat(jsonStr, strPtr(jsonFromBool(varBool(varSub))));
+                        strCat(jsonStr, jsonFromBool(varBool(varSub)));
                     }
                     else if (varType(varSub) == varTypeKeyValue)
                     {
-                        strCat(jsonStr, strPtr(jsonFromKvInternal(varKv(varSub))));
+                        strCat(jsonStr, jsonFromKvInternal(varKv(varSub)));
                     }
                     else if (varType(varSub) == varTypeVariantList)
                     {
-                        strCat(jsonStr, strPtr(jsonFromVar(varSub)));
+                        strCat(jsonStr, jsonFromVar(varSub));
                     }
                     else if (varType(varSub) == varTypeInt)
                     {
-                        strCat(jsonStr, strPtr(jsonFromInt(varInt(varSub))));
+                        strCat(jsonStr, jsonFromInt(varInt(varSub)));
                     }
                     else if (varType(varSub) == varTypeInt64)
                     {
-                        strCat(jsonStr, strPtr(jsonFromInt64(varInt64(varSub))));
+                        strCat(jsonStr, jsonFromInt64(varInt64(varSub)));
                     }
                     else if (varType(varSub) == varTypeUInt)
                     {
-                        strCat(jsonStr, strPtr(jsonFromUInt(varUInt(varSub))));
+                        strCat(jsonStr, jsonFromUInt(varUInt(varSub)));
                     }
                     else if (varType(varSub) == varTypeUInt64)
                     {
-                        strCat(jsonStr, strPtr(jsonFromUInt64(varUInt64(varSub))));
+                        strCat(jsonStr, jsonFromUInt64(varUInt64(varSub)));
                     }
                     else
                         jsonFromStrInternal(jsonStr, varStr(varSub));
                 }
 
                 // Close the array
-                strCat(jsonStr, "]");
+                strCatZ(jsonStr, "]");
             }
             // Else empty array
             else
-                strCat(jsonStr, "[]");
+                strCatZ(jsonStr, "[]");
         }
         else if (varType(var) == varTypeKeyValue)
         {
-            strCat(jsonStr, strPtr(jsonFromKvInternal(varKv(var))));
+            strCat(jsonStr, jsonFromKvInternal(varKv(var)));
         }
         else
             THROW(JsonFormatError, "variant type is invalid");
