@@ -133,6 +133,8 @@ infoPgLoadCallback(void *data, const String *section, const String *key, const V
         {
             .id = cvtZToUInt(strZ(key)),
             .version = pgVersionFromStr(varStr(kvGet(pgDataKv, INFO_KEY_DB_VERSION_VAR))),
+            .catalogVersion =
+                loadData->infoPg->type == infoPgBackup ? varUIntForce(kvGet(pgDataKv, INFO_KEY_DB_CATALOG_VERSION_VAR)) : 0,
 
             // This is different in archive.info due to a typo that can't be fixed without a format version bump
             .systemId = varUInt64Force(
@@ -223,13 +225,15 @@ infoPgAdd(InfoPg *this, const InfoPgData *infoPgData)
 
 /**********************************************************************************************************************************/
 InfoPg *
-infoPgSet(InfoPg *this, InfoPgType type, const unsigned int pgVersion, const uint64_t pgSystemId)
+infoPgSet(
+    InfoPg *this, InfoPgType type, const unsigned int pgVersion, const uint64_t pgSystemId, const unsigned int pgCatalogVersion)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(INFO_PG, this);
         FUNCTION_LOG_PARAM(ENUM, type);
         FUNCTION_LOG_PARAM(UINT, pgVersion);
         FUNCTION_LOG_PARAM(UINT64, pgSystemId);
+        FUNCTION_LOG_PARAM(UINT, pgCatalogVersion);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
@@ -250,6 +254,9 @@ infoPgSet(InfoPg *this, InfoPgType type, const unsigned int pgVersion, const uin
 
             // This is different in archive.info due to a typo that can't be fixed without a format version bump
             .systemId = pgSystemId,
+
+            // Catalog version is only required for backup info to preserve the repo format
+            .catalogVersion = this->type == infoPgBackup ? pgCatalogVersion : 0,
         };
 
         // Add the pg data to the history list
@@ -294,8 +301,7 @@ infoPgSaveCallback(void *data, const String *sectionNext, InfoSave *infoSaveData
         if (saveData->infoPg->type == infoPgBackup)
         {
             infoSaveValue(
-                infoSaveData, INFO_SECTION_DB_STR, varStr(INFO_KEY_DB_CATALOG_VERSION_VAR),
-                jsonFromUInt(pgCatalogVersion(pgData.version)));
+                infoSaveData, INFO_SECTION_DB_STR, varStr(INFO_KEY_DB_CATALOG_VERSION_VAR), jsonFromUInt(pgData.catalogVersion));
             infoSaveValue(
                 infoSaveData, INFO_SECTION_DB_STR, varStr(INFO_KEY_DB_CONTROL_VERSION_VAR),
                 jsonFromUInt(pgControlVersion(pgData.version)));
@@ -325,7 +331,7 @@ infoPgSaveCallback(void *data, const String *sectionNext, InfoSave *infoSaveData
                 kvPut(pgDataKv, INFO_KEY_DB_SYSTEM_ID_VAR, VARUINT64(pgData.systemId));
 
                 // These need to be saved because older pgBackRest versions expect them
-                kvPut(pgDataKv, INFO_KEY_DB_CATALOG_VERSION_VAR, VARUINT(pgCatalogVersion(pgData.version)));
+                kvPut(pgDataKv, INFO_KEY_DB_CATALOG_VERSION_VAR, VARUINT(pgData.catalogVersion));
                 kvPut(pgDataKv, INFO_KEY_DB_CONTROL_VERSION_VAR, VARUINT(pgControlVersion(pgData.version)));
             }
             else
@@ -486,5 +492,7 @@ infoPgCurrentDataId(const InfoPg *this)
 String *
 infoPgDataToLog(const InfoPgData *this)
 {
-    return strNewFmt("{id: %u, version: %u, systemId: %" PRIu64 "}", this->id, this->version, this->systemId);
+    return strNewFmt(
+        "{id: %u, version: %u, systemId: %" PRIu64 ", catalogVersion: %u}", this->id, this->version, this->systemId,
+        this->catalogVersion);
 }
