@@ -28,6 +28,7 @@ Main
 #include "command/stanza/create.h"
 #include "command/stanza/delete.h"
 #include "command/stanza/upgrade.h"
+#include "command/verify/verify.h"
 #include "common/debug.h"
 #include "common/error.h"
 #include "common/exit.h"
@@ -257,6 +258,14 @@ main(int argListSize, const char *argList[])
                     break;
                 }
 
+                // Verify command
+                // -----------------------------------------------------------------------------------------------------------------
+                case cfgCmdVerify:
+                {
+                    cmdVerify();
+                    break;
+                }
+
                 // Display version
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdVersion:
