@@ -361,7 +361,7 @@ sub containerBuild
                 "    yum -y install openssh-server openssh-clients wget sudo valgrind git \\\n" .
                 "        perl perl-Digest-SHA perl-DBD-Pg perl-YAML-LibYAML openssl \\\n" .
                 "        gcc make perl-ExtUtils-MakeMaker perl-Test-Simple openssl-devel perl-ExtUtils-Embed rpm-build \\\n" .
-                "        zlib-devel libxml2-devel lz4-devel lz4";
+                "        zlib-devel libxml2-devel lz4-devel lz4 bzip2-devel bzip2";
 
             if ($strOS eq VM_CO6)
             {
@@ -380,7 +380,8 @@ sub containerBuild
                 "    apt-get -y install openssh-server wget sudo gcc make valgrind git \\\n" .
                 "        libdbd-pg-perl libhtml-parser-perl libssl-dev libperl-dev \\\n" .
                 "        libyaml-libyaml-perl tzdata devscripts lintian libxml-checker-perl txt2man debhelper \\\n" .
-                "        libppi-html-perl libtemplate-perl libtest-differences-perl zlib1g-dev libxml2-dev pkg-config";
+                "        libppi-html-perl libtemplate-perl libtest-differences-perl zlib1g-dev libxml2-dev pkg-config \\\n" .
+                "        libbz2-dev bzip2";
 
             if ($strOS eq VM_U12)
             {
@@ -392,6 +393,19 @@ sub containerBuild
             }
         }
 
+        # Add zst command-line tool and development libs when available
+        if (vmWithZst($strOS))
+        {
+            if ($oVm->{$strOS}{&VM_OS_BASE} eq VM_OS_BASE_RHEL)
+            {
+                $strScript .= ' zstd libzstd-devel';
+            }
+            else
+            {
+                $strScript .= ' zstd libzstd-dev';
+            }
+        }
+
         # If no specific version of lcov is requested then install the default package
         if (!defined($oVm->{$strOS}{&VMDEF_LCOV_VERSION}))
         {
@@ -467,7 +481,7 @@ sub containerBuild
                         "    rpm -ivh \\\n" .
                         "        http://yum.postgresql.org/9.1/redhat/rhel-6-x86_64/pgdg-centos91-9.1-6.noarch.rpm \\\n" .
                         "        http://yum.postgresql.org/9.2/redhat/rhel-6-x86_64/pgdg-centos92-9.2-8.noarch.rpm \\\n" .
-                        "        https://download.postgresql.org/pub/repos/yum/11/redhat/rhel-6-x86_64/" .
+                        "        https://download.postgresql.org/pub/repos/yum/reporpms/EL-6-x86_64/" .
                             "pgdg-redhat-repo-latest.noarch.rpm && \\\n";
                 }
                 elsif ($strOS eq VM_CO7)
@@ -475,14 +489,14 @@ sub containerBuild
                     $strScript .=
                         "    rpm -ivh \\\n" .
                         "        http://yum.postgresql.org/9.2/redhat/rhel-7-x86_64/pgdg-centos92-9.2-3.noarch.rpm \\\n" .
-                        "        https://download.postgresql.org/pub/repos/yum/11/redhat/rhel-7-x86_64/" .
+                        "        https://download.postgresql.org/pub/repos/yum/reporpms/EL-7-x86_64/" .
                             "pgdg-redhat-repo-latest.noarch.rpm && \\\n";
                 }
-                elsif ($strOS eq VM_F30)
+                elsif ($strOS eq VM_F32)
                 {
                     $strScript .=
                         "    rpm -ivh \\\n" .
-                        "        https://download.postgresql.org/pub/repos/yum/reporpms/F-30-x86_64/" .
+                        "        https://download.postgresql.org/pub/repos/yum/reporpms/F-32-x86_64/" .
                             "pgdg-fedora-repo-latest.noarch.rpm && \\\n";
                 }
 
@@ -579,6 +593,8 @@ sub containerBuild
             if ($$oVm{$strOS}{&VM_OS_BASE} eq VM_OS_BASE_RHEL)
             {
                 $strScript .=
+                    # Don't allow sudo to disable core dump (suppresses errors, see https://github.com/sudo-project/sudo/issues/42)
+                    "    echo \"Set disable_coredump false\" >> /etc/sudo.conf && \\\n" .
                     "    echo '%" . TEST_GROUP . "        ALL=(ALL)       NOPASSWD: ALL' > /etc/sudoers.d/" . TEST_GROUP . " && \\\n" .
                     "    sed -i 's/^Defaults    requiretty\$/\\# Defaults    requiretty/' /etc/sudoers";
             }
