@@ -121,9 +121,9 @@ testRun(void)
         TEST_RESULT_INT(strLstSize(cfgCommandParam()), 1, "command param list is set");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_PTR(cfgExe(), NULL, "exe defaults to null");
+        TEST_RESULT_STR(cfgExe(), NULL, "exe defaults to null");
         TEST_RESULT_VOID(cfgExeSet(strNew("/path/to/exe")), "set exe");
-        TEST_RESULT_Z(strPtr(cfgExe()), "/path/to/exe", "exe is set");
+        TEST_RESULT_Z(strZ(cfgExe()), "/path/to/exe", "exe is set");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_BOOL(cfgOptionNegate(cfgOptConfig), false, "negate defaults to false");
@@ -200,7 +200,7 @@ testRun(void)
         TEST_ERROR(cfgOptionStr(cfgOptStanza), AssertError, "option 'stanza' is not valid for the current command");
         TEST_RESULT_VOID(cfgOptionValidSet(cfgOptStanza, true), "set stanza valid");
         TEST_ERROR(cfgOptionStr(cfgOptStanza), AssertError, "option 'stanza' is null but non-null was requested");
-        TEST_RESULT_PTR(cfgOptionStrNull(cfgOptStanza), NULL, "stanza defaults to null");
+        TEST_RESULT_STR(cfgOptionStrNull(cfgOptStanza), NULL, "stanza defaults to null");
         TEST_ERROR(
             cfgOptionSet(cfgOptStanza, cfgSourceParam, varNewDbl(1.1)), AssertError,
             "option 'stanza' must be set with String variant");
@@ -256,7 +256,7 @@ testRun(void)
         TEST_RESULT_VOID(cfgCommandSet(cfgCmdBackup, cfgCmdRoleDefault), "backup command");
 
         TEST_ERROR(
-            strPtr(varStr(cfgOptionDefaultValue(cfgDefOptDbInclude))), AssertError, "default value not available for option type 4");
+            strZ(varStr(cfgOptionDefaultValue(cfgDefOptDbInclude))), AssertError, "default value not available for option type 4");
         TEST_RESULT_STR_Z(varStr(cfgOptionDefault(cfgOptType)), "incr", "backup type default");
         TEST_RESULT_BOOL(varBool(cfgOptionDefault(cfgOptArchiveAsync)), false, "archive async default");
         TEST_RESULT_DOUBLE(varDbl(cfgOptionDefault(cfgOptProtocolTimeout)), 1830, "backup protocol-timeout default");
